#!/bin/sh

NAME=homedir-create.sh

USERNAME=$1
HOMEDIR=$2
USERUID=$3
USERGID=$4
MODE=$5

# Redhat Enterprise Linux may not have a path set so we must set it up.
PATH=$PATH:/bin:/usr/bin

# reset umask to make sure that we get newly created directories with permissions of 0755
umask 022

# Try to find a good chown binary - it may not be in our path
detectChown() {
  if [ -x /bin/chown ]; then CHOWN=/bin/chown;
  elif [ -x /usr/bin/chown ]; then CHOWN=/usr/bin/chown;
  elif [ -x /usr/sbin/chown ]; then CHOWN=/usr/sbin/chown; 
  else
    echo "$NAME Error: Could not detect a usable chown binary"
    exit 5
  fi
}

detectSkelDir() {
  OSX_SKELDIR="/System/Library/User Template"

  if [ -d "$OSX_SKELDIR" ]; then
    SKELDIRECTORY="$OSX_SKELDIR/Non_localized"
  else
    SKELDIRECTORY="/etc/skel"
  fi
  
  echo "Using skel dir: $SKELDIRECTORY"
}

copyFiles() {

  # If we're on AIX or another system that doesn't have /etc/skel but instead
  # has /usr/lib/security/mkuser.sys
  if [ -x /usr/lib/security/mkuser.sys ]; then
    MakeAIX
  else
    MakeOther
  fi
}

MakeAIX() {
	SHELL=`/opt/quest/bin/vastool nss getpwuid $USERUID | cut -d':' -f7`
    if [ -z "$SHELL" ] || [ ! -x "$SHELL" ]; then
      SHELL="/bin/csh"
    fi
	
    # Set the mode, which may be an override of what mkuser.sys sets)
    mkdir -p "$HOMEDIR"
    chmod $MODE "$HOMEDIR"
    $CHOWN $USERUID "$HOMEDIR"
    chgrp $USERGID "$HOMEDIR"
    if [ $? -ne 0 ]; then
        echo "$NAME Error: Failed to set permissions on home directory.";
        exit 4;
    fi

    if [ `basename $SHELL` != "csh" ] && [ ! -f "$HOMEDIR/.profile" ]
    then
            cp /etc/security/.profile "$HOMEDIR/.profile"
            chmod u+rwx,go-w "$HOMEDIR/.profile"
            $CHOWN $USERUID "$HOMEDIR/.profile"
            chgrp $USERGID "$HOMEDIR/.profile"
    
    else
       if [ `basename $SHELL` = "csh" ] && [ ! -f "$HOMEDIR/.login" ]
       then
            echo "#!/bin/csh" > "$HOMEDIR/.login"
            echo "set path = ( /usr/bin /etc /usr/sbin /usr/ucb \$HOME/bin /usr/bin/X11 /sbin . )" >> "$HOMEDIR/.login"
            echo "setenv MAIL \"/var/spool/mail/\$LOGNAME\"" >> "$HOMEDIR1/.login"
            echo "setenv MAILMSG \"[YOU HAVE NEW MAIL]\"" >> "$HOMEDIR/.login"
            echo "if ( -f \"\$MAIL\" && ! -z \"\$MAIL\") then" >> "$HOMEDIR/.login"
            echo "  echo \"\$MAILMSG\"" >> "$HOMEDIR/.login"
            echo "endif" >> "$HOMEDIR/.login"
            chmod u+rwx,go-w "$HOMEDIR/.login"
            $CHOWN $USERUID "$HOMEDIR/.login"
            chgrp $USERGID "$HOMEDIR/.login"
       fi
    fi
}

MakeOther() {
  # Figure out what skeleton directory we use
  detectSkelDir

  # Verify that the skel directory exists, the new homedir exists
  #  and we have a UID and GID 
  if [ -n "$HOMEDIR" ] && [ -n $MODE ] && [ -n $USERUID ] && [ -n $USERGID ]; then

    # Create the home Directory
    mkdir -p "$HOMEDIR"
    if [ $? -ne 0 ]; then
        echo "$NAME Error: Failed to create home directory.";
        exit 3;
    fi
    
    # Set permission for homedir (Note: This forces overriding system defaults)
    chmod $MODE "$HOMEDIR"
    if [ $? -ne 0 ]; then
        echo "$NAME Error: Failed to set permissions on home directory.";
        exit 4;
    fi
    
    # Set up the proper uid and guid for homedir
    $CHOWN $USERUID:$USERGID "$HOMEDIR"
    if [ $? -ne 0 ]; then
      echo "$NAME Error: Failed to set ownership on home directory - $HOMEDIR.";
      exit 5;
    fi

    ## The rest are non-critical, as a home directory does exist now
    # Change to skel directory to copy all files
    if [ -d "$SKELDIRECTORY" ]; then
      cd "$SKELDIRECTORY"
      if [ $? -ne 0 ]; then
        echo "$NAME Error: Failed to find skel directory.";
        exit 0;
      fi

      # Find all files and copy them
      find . | cpio -dp "$HOMEDIR"
      if [ $? -ne 0 ]; then
        echo "$NAME Error: Failed to copy skel files.";
        exit 0;
      fi
      
      # Reset the proper uid and guid for newly copied skel files
      $CHOWN -R $USERUID:$USERGID "$HOMEDIR"
      if [ $? -ne 0 ]; then
        echo "$NAME Error: Failed to set permissions.";
        exit 4;
      fi
    
      # Reset permission for homedir (On some UNIX's, the previous 'chown -R'
      # also sets the mode, which we don't want to do on the homedir)
      chmod $MODE "$HOMEDIR"
      if [ $? -ne 0 ]; then
        echo "$NAME Error: Failed to reset permissions on home directory.";
        exit 4;
      fi

      # If we're on Solaris we need to remove "local" from the start of each file
      for file in `ls -1 "$HOMEDIR/local*"`; do 
        new=`echo $file|cut -f2 -d'.'`; 
        mv $file "$HOMEDIR/.$new"
      done
    fi
  fi
}

if [ $# -ne 5 ]; then
  echo "Usage: $NAME {username} {homedir} {uid} {gid} {mode}"
  exit 1;
fi

if [ -d "$HOMEDIR" ]; then
  echo "User home directory already exists.";
  exit 2;
fi

detectChown

copyFiles

exit 0;
  
