#!/bin/sh

NAME=man.configure.aix
CONFIGFILE=/etc/environment


doConfigure() {
  MANDIR=$1
  if [ -f $CONFIGFILE ]; then
    grep -q $MANDIR $CONFIGFILE
    if [ $? -eq 0 ]; then
      echo "$CONFIGFILE already contains an entry for $MANDIR."
      exit 0;
    fi

    echo "Configuring global man path."
    # Use the default permissions for the OS
    umask 022
    grep -q "MANPATH" $CONFIGFILE
    if [ $? -ne 0 ]; then
      echo "MANPATH=$MANDIR:" >> $CONFIGFILE
      echo >> $CONFIGFILE
      exit 0;
    fi
    SEDCOMMAND="s~^MANPATH\=~MANPATH\=$MANDIR:~"
    sed "$SEDCOMMAND" $CONFIGFILE > $CONFIGFILE.tmp;
    if [ $? -eq 0 ]; then
      mv $CONFIGFILE.tmp $CONFIGFILE
    else
      echo "Failed to configure global man path."
      exit 1
    fi
  else
    echo "Could not find man configuration file."
    exit 3
  fi
  # Print on stderr so that users will see it on AIX
  echo "NOTE: man path changes will take effect at next login." 1>&2
}

doUnconfigure() {
  MANDIR=$1
  if [ -f $CONFIGFILE ]; then
    grep -q $MANDIR $CONFIGFILE
    if [ $? -eq 1 ]; then
      echo "$CONFIGFILE does not contain an entry for vas."
      exit 0;
    fi
    echo "Unconfiguring global man path."
    # Use the default permissions for the OS
    umask 022
    SEDCOMMAND="s~$MANDIR:~~"
    sed "$SEDCOMMAND" $CONFIGFILE > $CONFIGFILE.tmp
    if [ $? -eq 0 ]; then
      mv $CONFIGFILE.tmp $CONFIGFILE
    else
      echo "Failed to unconfigure global man path."
    fi
  else
    echo "Could not find man configuration file."
    exit 3
  fi
}

DIR=$2
if [ -z "$DIR"  ]
then
    DIR=/opt/quest/man
fi

case "$1" in
  configure)
    doConfigure $DIR
  ;;
  unconfigure)
    doUnconfigure $DIR
  ;;
  *)
  echo "Usage: $NAME {configure|unconfigure} {path}"
  exit 1
esac

exit 0
  
