#!/bin/sh

NAME=man.configure.uw
CONFIGFILE=/etc/default/man
DEFAULT_MANDIR=/opt/quest/man

doConfigure() {
  if [ -f $CONFIGFILE ]; then
    grep -q /opt/quest/man $CONFIGFILE
    if [ $? -eq 0 ]; then
      echo "$CONFIGFILE already contains an entry for vas."
      exit 0;
    fi
    echo "Configuring global man path."
    # Use the default permissions for the OS
    umask 022
    sed 's~^MANPATH\=~MANPATH\=/opt/quest/man:~' $CONFIGFILE > $CONFIGFILE.tmp;
    if [ $? -eq 0 ]; then
      mv $CONFIGFILE.tmp $CONFIGFILE
    else
      echo "Failed to configure global man path."
    fi
  else
    echo "Could not find man configuration file."
    exit 3
  fi
}

doUnconfigure() {
  if [ -f $CONFIGFILE ]; then
    grep -q /opt/quest/man $CONFIGFILE
    if [ $? -eq 1 ]; then
      echo "$CONFIGFILE does not contain an entry for vas."
      exit 0;
    fi
    echo "Unconfiguring global man path."
    # Use the default permissions for the OS
    umask 022
    sed 's~/opt/quest/man:~~' $CONFIGFILE > $CONFIGFILE.tmp
    if [ $? -eq 0 ]; then
      mv $CONFIGFILE.tmp $CONFIGFILE
    else
      echo "Failed to unconfigure global man path."
    fi
  else
    echo "Could not find man configuration file."
    exit 3
  fi
}

case "$1" in
  configure)
    doConfigure
  ;;
  unconfigure)
    doUnconfigure
  ;;
  *)
  echo "Usage: $NAME {configure|unconfigure}"
  exit 1
esac

exit 0
  
