#!/bin/sh

NAME=man.configure.hpux
CONFIGFILE=/etc/MANPATH

doConfigure() {
  MANDIR=$1
  if [ -f $CONFIGFILE ]; then
    grep -q $MANDIR $CONFIGFILE
    if [ $? -eq 0 ]; then
      echo "$CONFIGFILE already contains an entry for vas."
      exit 0;
    fi
    echo "Configuring global man path."
    # Use the default permissions for the OS
    umask 022
    SEDCOMMAND="s~\(.*\)~\1:$MANDIR~"
    sed "$SEDCOMMAND" $CONFIGFILE > $CONFIGFILE.tmp;
    if [ $? -eq 0 ]; then
      mv $CONFIGFILE.tmp $CONFIGFILE
      chmod 0444 $CONFIGFILE
    else
      echo "Failed to configure global man path."
    fi
  else
    echo "Could not find man configuration file."
    exit 3
  fi
}

doUnconfigure() {
  MANDIR=$1
  if [ -f $CONFIGFILE ]; then
    grep -q $MANDIR $CONFIGFILE
    if [ $? -eq 1 ]; then
      echo "$CONFIGFILE does not contain an entry for vas."
      exit 0;
    fi
    echo "Unconfiguring global man path."
    # Use the default permissions for the OS
    umask 022
    SEDCOMMAND="s~:$MANDIR~~"
    sed "$SEDCOMMAND" $CONFIGFILE > $CONFIGFILE.tmp
    if [ $? -eq 0 ]; then
      mv $CONFIGFILE.tmp $CONFIGFILE
      chmod 0444 $CONFIGFILE
    else
      echo "Failed to unconfigure global man path."
    fi
  else
    echo "Could not find man configuration file."
    exit 3
  fi
}

DIR=$2
if [ -z "$DIR"  ]
then
    DIR=/opt/quest/man
fi

case "$1" in
  configure)
    doConfigure $DIR
  ;;
  unconfigure)
    doUnconfigure $DIR
  ;;
  *)
  echo "Usage: $NAME {configure|unconfigure} {path}"
  exit 1
esac

exit 0
  
