#!/bin/sh

NAME=man.configure.manpath-config
CONFIGFILE=/etc/manpath.config

doConfigure() {
  MANDIR=$1
  if [ -f $CONFIGFILE ]; then
    grep -q $MANDIR $CONFIGFILE
    if [ $? -eq 0 ]; then
      echo "$CONFIGFILE already contains an entry for vas."
      exit 0
    fi
    echo "Adding path for $MANDIR to $CONFIGFILE."
    # Use the default permissions for the OS
    umask 022
    echo "MANDATORY_MANPATH       $MANDIR" >> $CONFIGFILE
    if [ $? -ne 0 ]; then
      echo "Failed to configure global man path, err = $?."
    fi
  else
    echo "Could not find man configuration file: $CONFIGFILE."
    exit 3
  fi
}

doUnconfigure() {
  MANDIR=$1
  if [ -f $CONFIGFILE ]; then
    grep -q $MANDIR $CONFIGFILE
    if [ $? -eq 1 ]; then
      echo "$CONFIGFILE does not contain an entry for vas."
      exit 0
    fi
    echo "Removing $MANDIR path from $CONFIGFILE."
    # Use the default permissions for the OS
    umask 022
    SEDCOMMAND="s~^MANDATORY_MANPATH*...*$MANDIR$~WHITESPACE~" 
    sed "$SEDCOMMAND" $CONFIGFILE > $CONFIGFILE.tmp
    sed '/WHITESPACE/d' $CONFIGFILE.tmp > $CONFIGFILE.tmp2
    rm $CONFIGFILE.tmp
    if [ $? -eq 0 ]; then
      mv $CONFIGFILE.tmp2 $CONFIGFILE
    else
      echo "Failed to unconfigure global man path."
    fi
  else
    echo "Could not find man configuration file: $CONFIGFILE."
    exit 3
  fi
}

DIR=$2
if [ -z "$DIR" ]
then
    DIR=/opt/quest/man
fi

case "$1" in
  configure)
    doConfigure $DIR
  ;;
  unconfigure)
    doUnconfigure $DIR
  ;;
  *)
  echo "Usage: $NAME {configure|unconfigure} {path}"
  exit 1
esac

exit 0
